@@ -526,26 +526,6 @@ magnifier_notify_damage (Magnifier *magnifier, XRectangle *rect)
 	magnifier_zoom_regions_mark_dirty (magnifier, rect_bounds);
 }
 
-GdkFilterReturn
-magnifier_expose_filter (GdkXEvent *xevent, GdkEvent *event, gpointer data)
-{
-	Magnifier *magnifier = data;
-
-	if (event->any.type == GDK_EXPOSE) 
-	{
-		GNOME_Magnifier_RectBounds rect_bounds;
-		GdkRectangle rect;
-		gdk_region_get_clipbox (event->expose.region, &rect);
-		rect_bounds.x1 = rect.x;
-		rect_bounds.y1 = rect.y;
-		rect_bounds.x2 = rect.x + rect.width;
-		rect_bounds.y2 = rect.y + rect.height;
-		magnifier_zoom_regions_mark_dirty (magnifier, rect_bounds);
-
-		return GDK_FILTER_TRANSLATE;
-	}
-	return GDK_FILTER_CONTINUE;
-}
 static void
 magnifier_set_extension_listeners (Magnifier *magnifier, GdkWindow *root)
 {
