@@ -51,6 +51,9 @@ typedef struct {
 	gfloat contrast;
 	gfloat xscale;
 	gfloat yscale;
+	gfloat contrast_r;
+	gfloat contrast_g;
+	gfloat contrast_b;
 	gint border_size;
 	guint32 border_color; /* A-RGB, 8 bits each, MSB==alpha */
 	gint x_align_policy;  /* TODO: enums here */
